import { createRESTModule } from '@wix/sdk-runtime/rest-modules';
import { FetchErrorResponse } from './fetch-error.js';
export const graphql = createRESTModule(((restModuleOpts) => {
    // eslint-disable-next-line @typescript-eslint/no-shadow
    return async function graphql(query, variables, opts = {
        apiVersion: 'alpha',
    }) {
        const res = await restModuleOpts.wixAPIFetch(`/graphql/${opts.apiVersion}`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({ query, variables }),
        });
        if (res.status !== 200) {
            throw new FetchErrorResponse(`GraphQL request failed with status ${res.status}`, res);
        }
        const { data, errors } = await res.json();
        return { data: data ?? {}, errors };
    };
}));
